==> lxqt-l10n_0.10.9.orig.tar.xz: lxqt-l10n-0.10.9/lxqt-panel/plugin-cpuload/cpuload_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation>Φορτίο επεξεργαστή %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="124"/>
        <source>CPU load %1%</source>
        <translation>Φορτίο επεξεργαστή %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation type="vanished">Ρυθμίσεις φορτίου ΚΜΕ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Ρυθμίσεις του Φορτίου επεξεργαστή</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Εμφάνιση κειμένου</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Διάστημα ενημέρωσης:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>δευτ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Προσανατολισμός ράβδου:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Πλάτος ράβδου:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Bottom up</source>
        <translation>Κάτω προς τα πάνω</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Top down</source>
        <translation>Πάνω προς τα κάτω</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="72"/>
        <source>Left to right</source>
        <translation>Αριστερά προς δεξιά</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="73"/>
        <source>Right to left</source>
        <translation>Δεξιά προς αριστερά</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-cpuload/cpuload_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>LXQtCpuLoad</name>
    <message>
        <source>Cpu load %1%</source>
        <translation>Φόρτος του επεξεργαστή %1%</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuload.cpp" line="125"/>
        <source>CPU load %1%</source>
        <translation>Φόρτος επεξεργαστή %1%</translation>
    </message>
</context>
<context>
    <name>LXQtCpuLoadConfiguration</name>
    <message>
        <source>LXQt Cpu Load settings</source>
        <translation>Ρυθμίσεις φόρτου επεξεργαστή του LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="14"/>
        <source>CPU Load Settings</source>
        <translation>Ρυθμίσεις του φόρτου του επεξεργαστή</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="35"/>
        <source>Show text</source>
        <translation>Εμφάνιση κειμένου</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="42"/>
        <source>Update interval:</source>
        <translation>Διάστημα ενημέρωσης:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="49"/>
        <source>sec</source>
        <translation>δευτ</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="71"/>
        <source>Bar orientation:</source>
        <translation>Προσανατολισμός ράβδου:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.ui" line="81"/>
        <source>Bar width:</source>
        <translation>Πλάτος ράβδου:</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="68"/>
        <source>Bottom up</source>
        <translation>Κάτω προς τα πάνω</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="69"/>
        <source>Top down</source>
        <translation>Πάνω προς τα κάτω</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="70"/>
        <source>Left to right</source>
        <translation>Αριστερά προς δεξιά</translation>
    </message>
    <message>
        <location filename="../../../lxqtcpuloadconfiguration.cpp" line="71"/>
        <source>Right to left</source>
        <translation>Δεξιά προς αριστερά</translation>
    </message>
</context>
</TS>
